@@ -7,13 +7,13 @@ import {
   Grid,
   FormCommonField,
   LoadingLinear,
+  MaterialIcon,
   Paper,
   Tab,
   Tabs,
   TitlebarControl,
   Typography
 } from 'system/components'
-import SubmitIcon from '@mui/icons-material/DoneRounded'
 import {
   ScreenProps,
   SettingsSchema,
@@ -147,13 +147,17 @@ export default class SettingsScreen extends React.Component<ScreenProps> {
       return null
 
     return (
-      <Box mt={2} mb={3}>
+      <Box mt={1}>
         <TitlebarControl title={gettext("Properties and settings", 'system.settings')} mb={3}>
           <Button
             color={'primary'}
             disabled={!Object.keys(this.state.values).length}
             variant={'contained'}
-            startIcon={this.state.submitting ? <CircularProgress size={20}/> : <SubmitIcon/>}
+            startIcon={
+              this.state.submitting
+                ? <CircularProgress size={20} />
+                : <MaterialIcon icon={'done'} />
+            }
             onClick={this.handleSubmit}
             style={{marginLeft: '8px'}}
           >{gettext("Save")}</Button>
@@ -175,7 +179,8 @@ export default class SettingsScreen extends React.Component<ScreenProps> {
                   wrapped
                   style={{
                     maxWidth: 'none',
-                    alignItems: 'flex-start'
+                    alignItems: 'flex-start',
+                    textAlign: 'left'
                   }}
                 />
               ))}
